@@ -1,6 +1,11 @@
 #include<R.h>
 #include<Rmath.h>
 #include<R_ext/Lapack.h>
+#include<R_ext/Applic.h>
+#include<R_ext/Print.h>
+#include <R_ext/Utils.h>
+
+
 /* type = 0, distances is a vector
  type = 1, distances is a symmetric matrix,
  only lower triangle is used
@@ -63,7 +68,7 @@ void computeBoxCox(
 		const int *N, // Nobs, Nrep
 		double *boxcox, //  Nrep by 3
 		// c 1: boxcox par; c 2: sum log(Y), c 3: two log jacobian
-		int *boxcoxType
+		const int boxcoxType
 		// 0= do nothing
 		// 1= do box-cox
 		// 2= put y in 1st column and log(y) in 2nd column of obscov
@@ -79,8 +84,8 @@ void maternLogLGivenChol(
 		double *totalSsq, // a 1 by Nrep matrix
 		double *betaHat, // an Ncov by Nrep matrix
 		double *varBetaHat, // an Ncov by Ncov by Nrep array
-		double *determinants // detVarHalf, detCholCovInvXcrossHalf
-		);
+		double *determinants, // detVarHalf, detCholCovInvXcrossHalf
+		double *LxLy);
 
 void maternLogLGivenVarU(
 		double *varMat, // variance matrix
@@ -96,9 +101,8 @@ void maternLogLGivenVarU(
 void logLfromComponents(
 		const int *N,
 		const double *boxcox,
-		const int *boxcoxType,
-		double *totalSsq,// length Nrep+1 logL on exit
-		double *totalVarHat,// length Nrep
+		const int boxcoxType,
+		double *totalSsq,// matrix Nrep by 2
 		const double *determinants,
 		const int *Ltype
 		// 0=ml, var estimated
